@@ -156,7 +156,12 @@ class Logging:
         #     / 'dat/ap_master_flat_col_array.dat', self.args)
         master_path = (Path(__file__).absolute().parent.parent
                        / 'dat/master_dome_flat_1.npy')
-        master_data = np.load(master_path)
+        try:
+            master_data = np.load(master_path.as_posix())
+        except FileNotFoundError:
+            master_path = (Path(__file__).absolute().parent.parent.parent
+                           / 'dat/master_dome_flat_1.npy')
+            master_data = np.load(master_path.as_posix())
 
         self.ap_master = np.average(master_data[:, 900:910], axis=1)
 
