@@ -11,13 +11,34 @@ except ImportError as e:
         from bin import epics_fetch
     except ImportError:
         raise ImportError(f'epics_fetch.py not in PYTHONPATH:\n {sys.path}')
+try:
+    import tpmdgram
+except ImportError:
+    print('tpmdgram unavailable')
+    tpmdgram = None
 
-import tpmdgram
 
 __version__ = '3.0.0'
 
 
-def query(sock, sz):
+def query():
+    if tpmdgram is None:
+        return
+    sz = tpmdgram.tinit()
+
+    multicast_group = '224.1.1.1'
+    server_address = ('', 2007)
+
+    # Init socket
+    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+
+    # Bind to the server address
+    sock.bind(server_address)
+
+    # Tell the OS to add the socket to the multicast group on all interfaces
+    group = socket.inet_aton(multicast_group)
+    mreq = struct.pack('4sL', group, socket.INADDR_ANY)
+    sock.setsockopt(socket.IPPROTO_IP, socket.IP_ADD_MEMBERSHIP, mreq)
     data, addr = sock.recvfrom(sz)
     data = tpmdgram.data2dict(data)
 
@@ -39,26 +60,14 @@ def query(sock, sz):
     output += f"LN2 autofill systems:  Connected and turned on\n"
     output += (f"180L LN2 dewar scale:  SP1 {data['dewar_sp1_lb']:6.1f} lbs,"
                f" {data['dewar_sp1_psi']:6.1f} psi")
+    sock.detach()
+    sock.close()
+
     return output
 
 
 def main():
-    sz = tpmdgram.tinit()
-
-    multicast_group = '224.1.1.1'
-    server_address = ('', 2007)
-
-    # Init socket
-    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-
-    # Bind to the server address
-    sock.bind(server_address)
-
-    # Tell the OS to add the socket to the multicast group on all interfaces
-    group = socket.inet_aton(multicast_group)
-    mreq = struct.pack('4sL', group, socket.INADDR_ANY)
-    sock.setsockopt(socket.IPPROTO_IP, socket.IP_ADD_MEMBERSHIP, mreq)
-    print(query(sock, sz))
+    print(query())
 
 
 if __name__ == '__main__':
